@@ -9,6 +9,7 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"regexp"
 	"sort"
 	"strings"
 	"text/tabwriter"
@@ -339,7 +340,7 @@ func (s ThreadState) String() string {
 			"   x24: %s  x25: %s  x26: %s  x27: %s\n"+
 			"   x28: %s   fp: %s   lr: %s\n"+
 			"    sp: %s   pc: %s cpsr: %s\n"+
-			"   esr: %s\n",
+			"   esr: %s %s\n",
 		fmtAddr(s.X[0].Value), fmtAddr(s.X[1].Value), fmtAddr(s.X[2].Value), fmtAddr(s.X[3].Value),
 		fmtAddr(s.X[4].Value), fmtAddr(s.X[5].Value), fmtAddr(s.X[6].Value), fmtAddr(s.X[7].Value),
 		fmtAddr(s.X[8].Value), fmtAddr(s.X[9].Value), fmtAddr(s.X[10].Value), fmtAddr(s.X[11].Value),
@@ -349,7 +350,7 @@ func (s ThreadState) String() string {
 		fmtAddr(s.X[24].Value), fmtAddr(s.X[25].Value), fmtAddr(s.X[26].Value), fmtAddr(s.X[27].Value),
 		fmtAddr(s.X[28].Value), fmtAddr(s.FP.Value), fmtAddr(s.LR.Value),
 		fmtAddr(s.SP.Value), fmtAddr(s.PC.Value), fmtAddrSmol(s.CPSR.Value),
-		fmtAddrSmol(s.ESR.Value))
+		fmtAddrSmol(s.ESR.Value), colorError(s.ESR.Description))
 }
 
 type UserThread struct {
@@ -556,7 +557,7 @@ func OpenIPS(in string) (*Ips, error) {
 	return &ips, nil
 }
 
-func (i *Ips) Symbolicate(ipswPath string) error {
+func (i *Ips) Symbolicate210(ipswPath string) error {
 	total := len(i.Payload.BinaryImages)
 
 	// add default binary image names
@@ -697,13 +698,26 @@ func fmtState(states []string) string {
 	return strings.Join(out, ", ")
 }
 
-func (i *Ips) String() string {
+func colorVMSummary(in string) string {
+	separatorMatch := regexp.MustCompile(`=+`)
+	in = separatorMatch.ReplaceAllStringFunc(in, func(s string) string {
+		return colorField(s)
+	})
+	return in
+}
+
+func (i *Ips) String(verbose bool) string {
 	var out string
 
 	switch i.Header.BugType {
 	case "Panic", "210":
 		out = fmt.Sprintf("[%s] - %s - %s %s\n\n", colorTime(i.Header.Timestamp.Format("02Jan2006 15:04:05")), colorError(i.Header.BugTypeDesc), i.Payload.Product, i.Payload.Build)
-		out += i.Payload.PanicString
+		p210, err := parsePanicString210(i.Payload.PanicString)
+		if err != nil {
+			out += i.Payload.PanicString
+		} else {
+			out += p210.String()
+		}
 		out += i.Payload.OtherString + "\n"
 		var pids []int
 		for pid := range i.Payload.ProcessByPid {
@@ -712,9 +726,25 @@ func (i *Ips) String() string {
 		sort.Ints(pids)
 		for _, pid := range pids {
 			p := i.Payload.ProcessByPid[pid]
-			out += fmt.Sprintf(colorField("Process:")+" %s [%s]\n", colorImage(p.Name), colorBold("%d", p.ID))
+			paniced := ""
+			if p.ID == p210.PanickedTask.PID {
+				paniced = colorError(" (Panicked)")
+			} else {
+				if !verbose {
+					continue
+				}
+			}
+			out += fmt.Sprintf(colorField("Process")+": %s [%s]%s\n", colorImage(p.Name), colorBold("%d", p.ID), paniced)
 			for _, t := range p.ThreadByID {
-				out += fmt.Sprintf(colorField("  Thread:")+" %s\n", colorBold("%d", t.ID))
+				paniced = ""
+				if t.ID == p210.PanickedThread.TID {
+					paniced = colorError("       (Panicked)")
+				} else {
+					if !verbose {
+						continue
+					}
+				}
+				out += fmt.Sprintf(colorField("  Thread")+": %s%s\n", colorBold("%d", t.ID), paniced)
 				if len(t.Name) > 0 {
 					out += fmt.Sprintf("    Name:           %s\n", colorTime(t.Name))
 				}
@@ -725,7 +755,7 @@ func (i *Ips) String() string {
 				out += fmt.Sprintf("    Base Priority:  %d\n", t.BasePriority)
 				out += fmt.Sprintf("    Sched Priority: %d\n", t.SchedPriority)
 				out += fmt.Sprintf("    User Time:      %d usec\n", t.UserUsec)
-				// out += fmt.Sprintf("    System Time:    %d usec\n", t.SystemUsec)
+				out += fmt.Sprintf("    System Time:    %d usec\n", t.SystemUsec)
 				if len(t.UserFrames) > 0 {
 					out += "    User Frames:\n"
 					buf := bytes.NewBufferString("")
@@ -760,28 +790,28 @@ func (i *Ips) String() string {
 	case "Crash", "309":
 		out = fmt.Sprintf("[%s] - %s\n\n", colorTime(i.Header.Timestamp.Format("02Jan2006 15:04:05")), colorError(i.Header.BugTypeDesc))
 		out += fmt.Sprintf(
-			colorField("Process:")+"             %s [%d]\n"+
-				colorField("Hardware Model:")+"      %s\n"+
-				colorField("OS Version:")+"          %s\n"+
-				colorField("BuildID:")+"             %s\n"+
-				colorField("LockdownMode:")+"        %d\n",
+			colorField("Process")+":             %s [%d]\n"+
+				colorField("Hardware Model")+":      %s\n"+
+				colorField("OS Version")+":          %s\n"+
+				colorField("BuildID")+":             %s\n"+
+				colorField("LockdownMode")+":        %d\n",
 			i.Payload.ProcName, i.Payload.PID,
 			i.Payload.ModelCode,
 			i.Payload.OsVersion.Train,
 			i.Payload.OsVersion.Build,
 			i.Payload.LockdownMode)
 		if i.Payload.SharedCache.Size > 0 {
-			out += fmt.Sprintf(colorField("Shared Cache:")+"        %s %s %#x %s %d\n", i.Payload.SharedCache.UUID, colorField("base:"), i.Payload.SharedCache.Base, colorField("size:"), i.Payload.SharedCache.Size)
+			out += fmt.Sprintf(colorField("Shared Cache")+":        %s %s: %#x %s: %d\n", i.Payload.SharedCache.UUID, colorField("base"), i.Payload.SharedCache.Base, colorField("size"), i.Payload.SharedCache.Size)
 		}
-		out += fmt.Sprintf("\n%s      %s (%s) %s\n", colorField("Exception Type:"), i.Payload.Exception.Type, i.Payload.Exception.Signal, i.Payload.Exception.Message)
+		out += fmt.Sprintf("\n%s:      %s (%s) %s\n", colorField("Exception Type"), i.Payload.Exception.Type, i.Payload.Exception.Signal, i.Payload.Exception.Message)
 		if len(i.Payload.Exception.Subtype) > 0 {
-			out += fmt.Sprintf("Exception Subtype:   %s\n", i.Payload.Exception.Subtype)
+			out += fmt.Sprintf(colorField("Exception Subtype")+":   %s\n", i.Payload.Exception.Subtype)
 		}
 		if len(i.Payload.VmRegionInfo) > 0 {
-			out += fmt.Sprintf("VM Region Info: %s\n", i.Payload.VmRegionInfo)
+			out += fmt.Sprintf(colorField("VM Region Info")+": %s\n", i.Payload.VmRegionInfo)
 		}
 		if i.Payload.Asi != nil {
-			out += colorField("ASI:\n")
+			out += colorField("ASI") + ":\n"
 			for k, v := range i.Payload.Asi {
 				out += fmt.Sprintf("    %s:\n", k)
 				for _, s := range v {
@@ -793,13 +823,13 @@ func (i *Ips) String() string {
 		for _, t := range i.Payload.Threads {
 			out += fmt.Sprintf(colorField("Thread")+" %s:", colorBold("%d", t.ID))
 			if len(t.Name) > 0 {
-				out += fmt.Sprintf(" name: %s", t.Name)
+				out += colorField(" name") + ": " + t.Name
 				if len(t.Queue) > 0 {
 					out += ","
 				}
 			}
 			if len(t.Queue) > 0 {
-				out += fmt.Sprintf(" queue: %s", t.Queue)
+				out += colorField(" queue") + ": " + t.Queue
 			}
 			if t.Triggered {
 				out += colorError(" (Crashed)\n")
@@ -820,12 +850,12 @@ func (i *Ips) String() string {
 				out += buf.String()
 			}
 			if t.Triggered {
-				out += fmt.Sprintf(colorField("Thread State:")+"\n%s", t.ThreadState)
+				out += colorField("Thread") + colorBold(" %d ", t.ID) + colorField(t.ThreadState.Flavor) + "\n" + t.ThreadState.String()
 			}
 			out += "\n"
 		}
 		if len(i.Payload.LastExceptionBacktrace) > 0 {
-			out += colorField("Last Exception Backtrace:\n")
+			out += colorField("Last Exception Backtrace") + ":\n"
 			buf := bytes.NewBufferString("")
 			w := tabwriter.NewWriter(buf, 0, 0, 1, ' ', 0)
 			for idx, f := range i.Payload.LastExceptionBacktrace {
@@ -835,7 +865,7 @@ func (i *Ips) String() string {
 			out += buf.String() + "\n"
 		}
 		if len(i.Payload.VMSummary) > 0 {
-			out += fmt.Sprintf("VM Summary: %s\n", i.Payload.VMSummary)
+			out += colorField("VM Summary") + ":\n" + colorVMSummary(i.Payload.VMSummary)
 		}
 	default:
 		return fmt.Sprintf("%s: (unsupported, notify author)", i.Header.BugType)
