@@ -1125,8 +1125,6 @@ func (f *File) parseSlideInfo(uuid mtypes.UUID, mapping *CacheMappingWithSlideIn
 			}
 		}
 	case 5:
-		log.Warnf("slide info version: %d, was added to macOS 14.4beta1 and I'm still working on REing it (stay tuned 😉)", slideInfoVersion)
-
 		slideInfo := CacheSlideInfo5{}
 		if err := binary.Read(sr, binary.LittleEndian, &slideInfo); err != nil {
 			return nil, err
@@ -1141,19 +1139,83 @@ func (f *File) parseSlideInfo(uuid mtypes.UUID, mapping *CacheMappingWithSlideIn
 		output(dump, "slide info version = %d\n", slideInfo.Version)
 		output(dump, "page_size          = %#x\n", slideInfo.PageSize)
 		output(dump, "page_starts_count  = %d\n", slideInfo.PageStartsCount)
-		output(dump, "auth_value_add     = %#x\n", slideInfo.AuthValueAdd)
+		output(dump, "auth_value_add     = %#x\n", slideInfo.ValueAdd)
 
-		// var targetValue uint64
-		// var pointer CacheSlidePointer3
+		var targetValue uint64
+		var pointer CacheSlidePointer5
 
-		// starts := make([]uint16, slideInfo.PageStartsCount)
-		// if err := binary.Read(sr, binary.LittleEndian, &starts); err != nil {
-		// 	return nil, err
-		// }
+		starts := make([]uint16, slideInfo.PageStartsCount)
+		if err := binary.Read(sr, binary.LittleEndian, &starts); err != nil {
+			return nil, err
+		}
 
-		// if endPage == 0 || endPage > uint64(len(starts)-1) {
-		// 	endPage = uint64(len(starts) - 1) // set end page to MAX
-		// }
+		if endPage == 0 || endPage > uint64(len(starts)-1) {
+			endPage = uint64(len(starts) - 1) // set end page to MAX
+		}
+
+		for i, start := range starts[startPage:endPage] {
+			i += int(startPage)
+			pageAddress := mapping.Address + uint64(uint32(i)*slideInfo.PageSize)
+			pageOffset := mapping.FileOffset + uint64(uint32(i)*slideInfo.PageSize)
+
+			delta := uint64(start)
+
+			if delta == DYLD_CACHE_SLIDE_V3_PAGE_ATTR_NO_REBASE {
+				output(dump, "page[% 5d]: no rebasing\n", i)
+				continue
+			}
+
+			output(dump, "page[% 5d]: start=0x%04X\n", i, delta)
+
+			rebaseLocation := pageOffset
+			rebaseAddr := pageAddress
+
+			for {
+				rebaseLocation += delta
+				rebaseAddr += delta
+
+				sr.Seek(int64(rebaseLocation), io.SeekStart)
+				if err := binary.Read(sr, binary.LittleEndian, &pointer); err != nil {
+					return nil, err
+				}
+
+				if pointer.Authenticated() {
+					targetValue = slideInfo.ValueAdd + pointer.Value()
+				} else {
+					targetValue = slideInfo.ValueAdd + pointer.SignExtend51()
+				}
+
+				if dump {
+					sym, ok := f.AddressToSymbol[targetValue]
+					if !ok {
+						symName = "?"
+					} else {
+						symName = sym
+					}
+					fmt.Printf("    [% 5d + 0x%05X] (off: %#x @ vaddr: %#x; raw: %#x => target: %#x) %s, sym: %s\n", i, (uint64)(rebaseLocation-pageOffset), rebaseLocation, rebaseAddr, pointer.Raw(), targetValue, pointer, symName)
+				} else {
+					sym, ok := f.AddressToSymbol[targetValue]
+					if !ok {
+						symName = ""
+					} else {
+						symName = sym
+					}
+					rebases = append(rebases, Rebase{
+						CacheFileOffset: rebaseLocation,
+						CacheVMAddress:  rebaseAddr,
+						Target:          targetValue,
+						Pointer:         pointer,
+						Symbol:          symName,
+					})
+				}
+
+				if pointer.OffsetToNextPointer() == 0 {
+					break
+				}
+
+				delta = pointer.OffsetToNextPointer() * 8
+			}
+		}
 	default:
 		log.Errorf("got unexpected dyld slide info version: %d", slideInfoVersion)
 	}
